@@ -5,6 +5,7 @@ Converts the last backward-compatible filebrowser branch into a newly named
 package ``filebrowser_safe``.
 """
 
+from __future__ import with_statement
 import os
 
 branch_url = \
@@ -14,22 +15,12 @@ package_name_to = "filebrowser_safe"
 
 if not os.path.exists(package_name_from):
     print "Checking out branch..."
-    os.system("svn co %s" % branch_url)
+    os.system("svn export %s" % branch_url)
 
 for (dirpath, dirnames, filenames) in os.walk(package_name_from, False):
-    for name in dirnames:
-        path = os.path.join(dirpath, name)
-        # Delete SVN directories.
-        if ".svn" in path:
-            print "Deleting svn %s" % path
-            os.rmdir(path)
     for name in filenames:
         path = os.path.join(dirpath, name)
-        # Delete SVN files.
-        if ".svn" in path:
-            print "Deleting svn %s" % path
-            os.remove(path)
-        elif path.endswith(".py"):
+        if path.endswith(".py"):
             update = False
             with open(path, "r") as f:
                 data = f.read()
@@ -51,5 +42,8 @@ for (dirpath, dirnames, filenames) in os.walk(package_name_from, False):
 
 # Move the package to the Mezzanine directory using the filebrowser_safe name.
 script_path = os.path.dirname(os.path.abspath(__file__))
-os.renames(package_name_from, os.path.join(script_path, "..", "..",
-    package_name_to))
+package_path_to = os.path.join(script_path, "..", "..", package_name_to)
+os.renames(package_name_from, package_path_to)
+# Create an empty ``Image`` module which will prevent having no PIL breaking.
+with open(os.path.join(package_path_to, "Image.py"), "w") as f:
+    f.write("")
